package GCExport;

###################################################
#
#  Copyright 2005 Tian
#
#  This file is part of GCfilms.
#
#  GCfilms is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCfilms is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCfilms; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################

use File::Basename;
use FindBin qw($RealBin);

use base 'Exporter';
our @EXPORT = qw(@exportersArray);

our @exportersArray;

foreach (glob $RealBin."/../lib/gcfilms/GCExport/*.pm")
{
    my $export = basename($_, '.pm')."\n";
    next if $export =~ /GCExportBase/;
    eval "use GCExport::$export";
    (my $exporter = $export) =~ s/^GCExport/GCExporter/;
    my $obj;
    eval "\$obj = new GCExport::$exporter";
    die "Fatal error with exporter $export\n$@" if $@;
    push @exportersArray, $obj if ! $obj->{errors};
}

use Gtk2;
use GCDialogs;

{
    #Class that is used to let user select
    #fields needed in export.
    package GCExportFieldsDialog;
    use base GCDoubleListDialog;
    
    sub getInitData
    {
        my $self = shift;
        my @array = values %{$self->{parent}->{lang}->{FieldsList}};
        return \@array;
    }
    
    sub getData
    {
        my $self = shift;
        
        my @array;
        foreach (@{$self->{parent}->{fields}})
        {
            push @array, $self->{parent}->{lang}->{FieldsList}->{$_};
        }
        
        return \@array;
    }
    
    sub saveList
    {
        my ($self, $list) = @_;
        
        my @array;
        foreach (@{$list})
        {
            push @array, $self->{fieldNameToId}->{$_};
        }
        $self->{parent}->{fields} = \@array;
    }
             
    sub getUnusedLabel
    {
        my $self = shift;
        
        return $self->{parent}->{lang}->{ExportFieldsUnused};
    }
    sub getUsedLabel
    {
        my $self = shift;
        
        return $self->{parent}->{lang}->{MultiSiteUsed};
    }
           
            
    sub new
    {
        my ($proto, $parent) = @_;
        my $class = ref($proto) || $proto;
        my $self  = $class->SUPER::new(
                                $parent,
                                $parent->{lang}->{ExportFieldsTitle}
                            );
        bless ($self, $class);
        
        my $fillButton = new Gtk2::Button($parent->{lang}->{ExportFieldsFill});
        $fillButton->signal_connect('clicked' => sub {
            $self->fillList;
        });
        my $clearButton = new Gtk2::Button($parent->{lang}->{ExportFieldsClear});
        $clearButton->signal_connect('clicked' => sub {
            $self->clearList;
        });            
        
        $self->{hboxAction}->pack_start($fillButton,1,1,10);
        $self->{hboxAction}->pack_start($clearButton,1,1,10);
        
        $self->{fieldNameToId} = {};
        while (($key, $value) = each %{$self->{parent}->{lang}->{FieldsList}})
        {
            $self->{fieldNameToId}->{$value} = $key;
        }
        
        $self->{scrollPanelUnused}->set_size_request(200,-1);
        $self->{scrollPanelUsed}->set_size_request(200,-1);        
        
        return $self;
    }
}


{
    package GCExportDialog;
    use base "Gtk2::Dialog";

    sub selectFile
    {
        my ($widget, $self) = @_;
        $self->{fileDialog}->set_filename($self->{file}->get_text);
		my $response = $self->{fileDialog}->run;
		if ($response eq 'ok')
		{
	            $self->{file}->set_text($self->{fileDialog}->get_filename);
		}
        $self->{fileDialog}->hide;
    }

    sub show
    {
        my $self = shift;
        $self->SUPER::show();
        $self->show_all;
        $self->resize(1,1);
        my $ok = 0;
        while (!$ok)
        {
            my $response = $self->run;
            if ($response eq 'ok')
            {
                if (($self->{exporter}->wantsFieldsSelection)
                    && (scalar @{$self->{fields}} == 0))
                {
                    my $dialog = Gtk2::MessageDialog->new($self,
                                                              [qw/modal destroy-with-parent/],
                                                              'error',
                                                              'ok',
                                                              $self->{parent}->{lang}->{ExportFieldsEmpty});
                    $dialog->run();
                    $dialog->destroy;
                    next;
                }
                my $file = $self->{file}->get_text;
                if ($file)
                {
                    my %options = $self->getOptions;     
                    $options{movies} = $self->{parent}->{movies}->{movieArray};
                    $options{file} = $file;
                    $options{collection} = $self->{parent}->{options}->file;
                    $options{lang} = $self->{parent}->{lang};
                    $options{fields} = $self->{fields};
                    
                    my $info = $self->{exporter}->export(\%options);
                    if ($info)
                    {
                        my $dialog = Gtk2::MessageDialog->new($self,
                                                              [qw/modal destroy-with-parent/],
                                                              'info',
                                                              'ok',
                                                              $info);
                        $dialog->run();
                        $dialog->destroy ;
                    }
                }
            }
            $ok = 1;
        }
        $self->hide;
    }

    sub setExporter
    {
        my ($self, $exporter) = @_;

        $self->set_title($self->{parent}->{lang}->{ExportTitle}." [".$exporter->getName."]");
        
        foreach ($self->{optionsVbox}->get_children)
        {
            $self->{optionsVbox}->remove($_);
        }
        
        $self->{exporter} = $exporter;
        my %options;
        my $option;
        foreach $option (@{$exporter->getOptions})
        {
            my $label = $self->{parent}->{lang}->{$option->{label}};
            my $widget;
            my $type = $option->{type};
            my $value = ((exists $exporter->{options}) ? $exporter->{options}->{$option->{name}} : $option->{default});
            if ($type eq 'checkBox')
            {
                $widget = new Gtk2::CheckButton($label);
                $widget->set_active($value);
            }
            elsif ( ($type eq 'shortText') || 
                      ($type eq 'longText') ||
                      ($type eq 'number') ||
                      ($type eq 'list'))
            {
                my $expand = 0;
                $widget = new Gtk2::HBox(0,0);
                $widget->pack_start(new Gtk2::Label($label), 0,0,0);
                my $in;

                if ($type eq 'shortText')
                {
                    $in = new Gtk2::Entry;
                    $in->set_text($value);
                    $expand = 1;
                }
                elsif ($type eq 'longText')
                {
                    my $text = new Gtk2::TextView;
                    $text->set_editable(1);
                    $text->set_wrap_mode('word');
                    $in = new Gtk2::ScrolledWindow;
                    $in->set_border_width(2);
                    $in->set_shadow_type('in');
                    $in->set_policy('automatic', 'automatic');
                    $in->set_size_request(-1,$option->{height});
                    $in->add($text);
                    $expand = 1;
                }
                elsif ($type eq 'number')
                {
                    my  $adj = Gtk2::Adjustment->new($value, $option->{min}, $option->{max}, 1, 1, 0) ;
                    $in = new Gtk2::SpinButton($adj, 0, 0);
                }
                elsif ($type eq 'list')
                {
                    $in = new Gtk2::OptionMenu();
                    my $menu = new Gtk2::Menu();
                    my @values = split m/,/, $option->{valuesList};
                    my $i = 0;
                    my $current;
                    foreach (@values)
                    {
                        my $item = Gtk2::MenuItem->new_with_label($_);
                        $current = $i if ($_ eq $value);
                        $menu->append( $item);
                        $i++;
                    }
                    $menu->set_active($current);
                    $in->set_menu($menu);
                }
                $widget->pack_start($in, $expand,$expand,5);
            }
            elsif (($type eq 'fileSelection') || ($type eq 'colorSelection'))
            {
                $widget = new Gtk2::HBox(0,0);
                $widget->pack_start(new Gtk2::Label($label), 0,0,0);
                my $entry = new Gtk2::Entry;
                $entry->set_text($value);
                $widget->pack_start($entry, 1,1,5);
                my $stock;
                my $callback;
                if ($type eq 'fileSelection')
                {
                    $stock = 'gtk-open';
                    $callback = sub {
                        my $dialog = new GCFileChooserDialog($label, $self, 'open');
                        $dialog->set_filename($entry->get_text);
                        my $response = $dialog->run;
                        if ($response eq 'ok')
                        {
                            $entry->set_text($dialog->get_filename);
                        }
                        $dialog->destroy;
                    }
                }
                else
                {
                    $stock = 'gtk-select-color';
                    $callback = sub {
                        my $dialog = new Gtk2::ColorSelectionDialog($label);
                        my $previous = Gtk2::Gdk::Color->parse($entry->get_text);
                        $dialog->colorsel->set_current_color($previous) if $previous;
                        my $response = $dialog->run;
                        if ($response eq 'ok')
                        {
                            my $color = $dialog->colorsel->get_current_color;
                            my $red = $color->red / 257;
                            my $blue = $color->blue / 257;
                            my $green = $color->green / 257;
                            my $colorString = sprintf ("#%X%X%X", $red, $blue, $green);
                            $entry->set_text($colorString);
                        }
                        $dialog->destroy;
                    }
                }
                
                my $button = Gtk2::Button->new_from_stock($stock);
                $button->signal_connect('clicked' => $callback);
                $widget->pack_start($button, 0,0,0);
            }
            
            $self->{optionsVbox}->pack_start($widget,0,0,5);
            $options{$option->{name}} = $widget;
        }
        
        if ($exporter->wantsFieldsSelection)
        {
            my $hboxFields = new Gtk2::HBox(0,0);
            $hboxFields->set_border_width(0);
            my $button = new Gtk2::Button($self->{parent}->{lang}->{ExportFieldsTitle});
            $self->{parent}->{tooltips}->set_tip($button,
                                     $self->{parent}->{lang}->{ExportFieldsTip});
            $hboxFields->pack_start($button,1,1,20);
            $self->{optionsVbox}->pack_start(new Gtk2::HSeparator, 1, 1, 5);
            $self->{optionsVbox}->pack_start($hboxFields,0,0,0);
            $button->signal_connect('clicked' => sub {
                $self->{fieldsDialog}->show;
            });
        }
        
        $self->{options} = \%options;
        $self->{optionsVbox}->show_all;
    }
    
    sub getOptions
    {
        my $self = shift;
        my %result;
        
        foreach (keys %{$self->{options}})
        {
            my $value;
            my $widget = $self->{options}->{$_};
            if ($widget->isa('Gtk2::HBox'))
            {
                $widget = ($widget->get_children)[1];
                if ($widget->isa('Gtk2::Entry'))
                {
                    $value = $widget->get_text;
                }
                elsif ($widget->isa('Gtk2::SpinButton'))
                {
                    $value = $widget->get_value;
                }
                elsif ($widget->isa('Gtk2::OptionMenu'))
                {
                    $value = $widget->child->get_label;
                }
                elsif ($widget->isa('Gtk2::ScrolledWindow'))
                {
                    my $buffer = $widget->child->get_buffer;
                    $value = $buffer->get_text($buffer->get_start_iter,
                                               $buffer->get_end_iter, 1);
                }
            }
            elsif ($widget->isa('Gtk2::CheckButton'))
            {
                $value = $widget->get_active
            }
            $result{$_} = $value;
        }
        
        return %result;
    }
    
    sub new
    {
        my ($proto, $parent) = @_;
        my $class = ref($proto) || $proto;
        my $self  = $class->SUPER::new($parent->{lang}->{ExportTitle},
                              $parent,
                              [qw/modal destroy-with-parent/],
                              'gtk-ok' => 'ok',
                              'gtk-cancel' => 'cancel'
                              );

        $self->{parent} = $parent;
        $self->{lang} = $parent->{lang};
        $self->{fields} = [];
        
        $self->{optionsVbox} = new Gtk2::VBox(0,0);

        my $sep = new Gtk2::HSeparator;

        my $hbox = new Gtk2::HBox(0,0);
        my $labelFile = new Gtk2::Label($parent->{lang}->{ExportFile});
        $self->{file} = new Gtk2::Entry;
        my $button = Gtk2::Button->new_from_stock('gtk-open');
        $button->signal_connect('clicked', \&selectFile, $self);
        $hbox->pack_start($labelFile,0,0,5);
        $hbox->pack_start($self->{file},0,0,5);
        $hbox->pack_start($button,0,0,5);

        $self->vbox->set_homogeneous(0);
        $self->vbox->pack_start($self->{optionsVbox},1,1,10);
        $self->vbox->pack_start($sep, 1, 1, 2);
        $self->vbox->pack_start($hbox, 1, 1, 10);

        $self->{fileDialog} = new GCFileChooserDialog($parent->{lang}->{ExportSave}, $parent, 'save');
        $self->{fieldsDialog} = new GCExportFieldsDialog($self);

        bless ($self, $class);
        return $self;
    }
    
}


1;
