package GCOptions;

###################################################
#
#  Copyright 2005 Tian
#
#  This file is part of GCfilms.
#
#  GCfilms is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCfilms is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCfilms; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################

use strict;

{
    package GCOptionLoader;

    sub new
    {
        my ($proto, $file) = @_;
        my $class = ref($proto) || $proto;
        my $self  = {};
        
        bless ($self, $class);
        $self->load($file);
        return $self;
    }

    sub setParent
    {
        my ($self, $parent) = @_;
        $self->{parent} = $parent;
    }

    sub load
    {
        my ($self, $file) = @_;

        $self->{file} = $file;

        $self->{options} = undef;

        if (! -e $file)
        {
            open OPTIONS, ">$file" or $self->{parent}->optionsError('create');
            printf OPTIONS 'images='.$ENV{GCF_DATA_HOME}.'/images/
autosave=1
browser=firefox
file='.$ENV{GCF_DATA_HOME}.'/films.gcf
order==0
split=300
width=920
height=640
confirm=1
lang=FR
status=1
splash=1
toolbar=1
status=1
transform=0
articles=le,la,les,l,un,une,des,a,the
plugin=ask
askImport=0
proxy=
borrowers=
emails=
view=0
columns=3
mailer=Sendmail
from=
subject=Rappel GCfilms
smtp=
template=Bonjour %1,<br><br>Tu m\'as emprunt %2 depuis le %3. J\'aimerais le rcuprer prochainement.
';
            close OPTIONS;
        }

        open OPTIONS, $file or $self->{parent}->optionsError('open');
        
        while (<OPTIONS>)
        {
            chomp;
            my @assign =  split m/=/;
            $self->{options}->{$assign[0]} = $assign[1];
        }
                
        close OPTIONS;
    }

    sub save
    {
        my $self = shift;

        open OPTIONS, '>'.$self->{file} or $self->{parent}->optionsError('save');
   
        my %options = %{$self->{options}};
     
        my $line = '';
		my $key;
		my $value;
        while (($key,$value) = each(%options))
        {
            $line = $key.'='.$value;

            printf OPTIONS "$line\n";            
        }
        
        close OPTIONS;
    }

    sub exists
    {
        my ($self, $name) = @_;
        
        return exists $self->{options}->{$name};
    }

    sub AUTOLOAD
    {
        my $self = shift;
        my $name = our $AUTOLOAD;
        return if $name =~ /::DESTROY$/;
        $name =~ s/.*?::(.*)/$1/;
        if (@_)
        {
            $self->{options}->{$name} = shift;
        }
        else
        {
            return $self->{options}->{$name};
        }
    }
}

{
    package GCOptionsDialog;
    use GCPlugins;
    use GCLang;
    use base "Gtk2::Dialog";

    sub on_destroy
    {
        my ($widget, $self) = @_;
        return 1;
    }

    sub initValues
    {
        my $self = shift;
        
        $self->{browser}->set_text($self->{options}->browser);
        $self->{images}->set_text($self->{options}->images);
        $self->{confirm}->set_active($self->{options}->confirm);
        $self->{autosave}->set_active($self->{options}->autosave);
        $self->{splash}->set_active($self->{options}->splash);
        $self->{status}->set_active($self->{options}->status);
        $self->{proxycb}->set_active($self->{options}->proxy);
		$self->{proxyurl}->set_text($self->{options}->proxy);
        $self->{transform}->set_active($self->{options}->transform);
        $self->{articles}->set_text($self->{options}->articles);
        $self->{formats}->set_text($self->{options}->formats);

        $self->{options}->columns(3) if ! $self->{options}->exists('columns');
        $self->{columns}->set_value($self->{options}->columns);

        $self->{options}->toolbar(1) if ! $self->{options}->exists('toolbar');
        $self->{toolbar}->set_active($self->{options}->toolbar);
        $self->{toolbarOption}->remove_menu;
        $self->{toolbarOption}->set_menu($self->{toolbar});

        $self->{options}->view(0) if ! $self->{options}->exists('view');
        $self->{view}->set_active($self->{options}->view);
        $self->{viewOption}->remove_menu;
        $self->{viewOption}->set_menu($self->{view});
       
        my @plugins = @{$self->{plugins}};
		$self->{options}->plugin('ask') if ! $self->{options}->exists('plugin');
        my $i = 0;
        foreach (@plugins)
        {
            last if ($self->{options}->plugin eq 'ask')
                     || ($self->{options}->plugin eq 'multi')
										 || ($self->{options}->plugin eq 'multiask')
                     || ($_ eq $self->{options}->plugin);
            $i++;
        }
        $i++ if $self->{options}->plugin eq 'multiask';
        $i = $i + 2 if $self->{options}->plugin eq 'multi';
        $self->{plugin}->set_active($i);
        $self->{pluginOption}->remove_menu;
        $self->{pluginOption}->set_menu($self->{plugin});

        $self->{askImport}->set_active($self->{options}->askImport);
        $self->{searchStop}->set_active($self->{options}->searchStop);
        
        my @langs= @{$self->{langs}};

        my $langCurrent = $self->{parent}->{lang}->{LangName};
        $i = 0;
        foreach (@langs)
        {
            last if ($_ eq $langCurrent);
            $i++;
        }
        $self->{lang}->set_active($i);
        $self->{langOption}->remove_menu;
        $self->{langOption}->set_menu($self->{lang});

        $self->{order}->set_active($self->{options}->order);
        $self->{orderOption}->remove_menu;
        $self->{orderOption}->set_menu($self->{order});        
        
        $self->{options}->mailer('Sendmail') if ! $self->{options}->exists('mailer');
        my $mailer = ($self->{options}->mailer eq 'Sendmail') ? 0 : 1;
        $self->{mailer}->set_active($mailer);
        $self->{mailerOption}->remove_menu;
        $self->{mailerOption}->set_menu($self->{mailer});

        $self->{from}->set_text($self->{options}->from);
        
        $self->{options}->listBgColor('65535,65535,65535') if ! $self->{options}->exists('listBgColor');
        $self->{options}->listFgColor('0,0,0') if ! $self->{options}->exists('listFgColor');
        $self->{mlbg} = $self->{options}->listBgColor;
        $self->{mlfg} = $self->{options}->listFgColor;
        
        $self->{proxyurl}->set_editable(0) if ! $self->{proxycb}->get_active;
        $self->{proxyurl}->set_editable(1) if $self->{proxycb}->get_active;
    }
    
    sub show
    {
        my $self = shift;

        $self->initValues;
        
        $self->show_all;
        $self->{hboxImages}->hide if $self->{options}->view == 0;
        $self->{hboxSMTP}->hide if $self->{options}->mailer eq 'Sendmail';
        $self->{pluginList}->hide if (($self->{options}->plugin ne 'multi') && ($self->{options}->plugin ne 'multiask'));

        my $code = $self->run;
        if ($code eq 'ok')
        {
            $self->{options}->browser($self->{browser}->get_text);
            $self->{options}->images($self->{images}->get_text);
	        $self->{options}->confirm(($self->{confirm}->get_active) ? 1 : 0);
	        $self->{options}->autosave(($self->{autosave}->get_active) ? 1 : 0);
	        $self->{options}->status(($self->{status}->get_active) ? 1 : 0);
	        $self->{options}->splash(($self->{splash}->get_active) ? 1 : 0);
	        $self->{options}->transform(($self->{transform}->get_active) ? 1 : 0);
            $self->{options}->articles($self->{articles}->get_text);
            $self->{options}->formats($self->{formats}->get_text);

            if ($self->{proxycb}->get_active)
		    {
	            $self->{options}->proxy($self->{proxyurl}->get_text);
		    }
		    else
		    {
	            $self->{options}->proxy('');
		    }
	
	        my $lang = $self->{langOption}->child->get_label;
            foreach (keys %GCLang::langs)
            {
                $self->{options}->lang($_);
                last if $GCLang::langs{$_}->{LangName} eq $lang;
            }
            
            my $order = $self->{orderOption}->child->get_label;
            my $i = 0;
            foreach (@{$self->{orders}})
            {
                $self->{options}->order($i);
                last if $_ eq $order;
                $i++;
            }
	
	        my %toolbars = %{$self->{parent}->{lang}->{OptionsToolbars}};
	        foreach my $i (0..(scalar(keys %toolbars) - 1))
	        {
	            $self->{options}->toolbar($i);
	            last if $toolbars{$i} eq $self->{toolbarOption}->child->get_label;
	        }

            my $currentView = $self->{options}->view;
            my %views = %{$self->{parent}->{lang}->{OptionsViews}};
	        foreach my $i (0..(scalar(keys %views) - 1))
	        {
	            $self->{options}->view($i);
	            last if $views{$i} eq $self->{viewOption}->child->get_label;
	        }
            
            my $currentColumns = $self->{options}->columns;
            my $currentBg = $self->{options}->listBgColor;
            my $currentFg = $self->{options}->listFgColor;
            $self->{options}->columns($self->{columns}->get_value);
            $self->{options}->listBgColor($self->{mlbg});
            $self->{options}->listFgColor($self->{mlfg});
            
            if (($currentView != $self->{options}->view)
             || ($currentColumns != $self->{options}->columns)
             || ($currentBg != $self->{options}->listBgColor)
             || ($currentFg != $self->{options}->listFgColor))
            {
                $self->{parent}->setMoviesList($self->{options}->view,
                                                             $self->{options}->columns);
            }
		    
		    my $selPlugin = $self->{pluginOption}->child->get_label;
		    my $plugin = 'ask';
		    foreach (@{$self->{plugins}})
		    {
				last if $selPlugin eq $self->{parent}->{lang}->{OptionsAskPlugins};
                last if $selPlugin eq $self->{parent}->{lang}->{OptionsPluginsMulti};
                last if $selPlugin eq $self->{parent}->{lang}->{OptionsPluginsMultiAsk};
				$plugin = $_;
				last if $plugin eq $selPlugin;
		    }
		    $plugin = 'multi' if $selPlugin eq $self->{parent}->{lang}->{OptionsPluginsMulti};
		    $plugin = 'multiask' if $selPlugin eq $self->{parent}->{lang}->{OptionsPluginsMultiAsk};
		    $self->{options}->plugin($plugin);
       
            $self->{options}->askImport(($self->{askImport}->get_active) ? 1 : 0);
            $self->{options}->searchStop(($self->{searchStop}->get_active) ? 1 : 0);

            $self->{options}->mailer($self->{mailerOption}->child->get_label);
            $self->{options}->smtp($self->{smtp}->get_text);
	        $self->{options}->from($self->{from}->get_text);
            
	        $self->{parent}->checkImagesDirectory(1);	       

	        $self->{options}->save;
	    }
        $self->hide;
    }

    sub browserBrowse
    {
        my ($widget, $self) = @_;
        $self->{browserDialog}->set_filename($self->{browser}->get_text);
		my $response = $self->{browserDialog}->run;
		if ($response eq 'ok')
		{
	            $self->{browser}->set_text($self->{browserDialog}->get_filename);
		}
        $self->{browserDialog}->hide;
    }

    sub imagesBrowse
    {
        my ($widget, $self) = @_;
        $self->{imagesDialog}->set_filename($self->{images}->get_text);
        my $response = $self->{imagesDialog}->run;
		if ($response eq 'ok')
		{
	            $self->{images}->set_text($self->{imagesDialog}->get_filename);
		}
        $self->{imagesDialog}->hide;
    }

    sub changeColor
    {
        my ($self, $type) = @_;
        
        my $dialog = new Gtk2::ColorSelectionDialog($self->{parent}->{lang}->{OptionsSelectColor});
        my @colors = split m/,/, $self->{'ml'.$type};
        my $previous = new Gtk2::Gdk::Color($colors[0], $colors[1], $colors[2]);
        $dialog->colorsel->set_current_color($previous) if $previous;
        my $response = $dialog->run;
        if ($response eq 'ok')
        {
            my $color = $dialog->colorsel->get_current_color;
            $self->{'ml'.$type} = join ',',$color->red, $color->green, $color->blue;
        }
        $dialog->destroy;
    }

    sub new
    {
        my ($proto, $parent, $options) = @_;
        my $class = ref($proto) || $proto;
        my $self  = $class->SUPER::new($parent->{lang}->{OptionsTitle},
                              $parent,
                              [qw/modal destroy-with-parent/],
                              'gtk-ok' => 'ok',
                              'gtk-cancel' => 'cancel'
                            );

        $self->set_has_separator(0);

        $self->{options} = $options;
        
        $self->{parent} = $parent;

        my $tablePath = new Gtk2::Table(2, 3, 0);
        $tablePath->set_row_spacings(10);
        $tablePath->set_col_spacings(10);
        $tablePath->set_border_width(20);

        my $labelBrowser = new Gtk2::Label($parent->{lang}->{OptionsBrowser});
        $labelBrowser->set_alignment(0,0.5);
        $tablePath->attach($labelBrowser, 0, 1, 0, 1, 'fill', 'fill', 0, 0);
        $self->{browser} = new Gtk2::Entry;
        $self->{browser}->set_width_chars(50);
        $tablePath->attach($self->{browser}, 1, 2, 0, 1, 'expand', 'fill', 0, 0);
        my $browserButton = Gtk2::Button->new_from_stock('gtk-open');
        $browserButton->signal_connect('clicked', \&browserBrowse, $self);
        $tablePath->attach($browserButton, 2, 3, 0, 1, 'fill', 'fill', 0, 0);

        my $labelImages = new Gtk2::Label($parent->{lang}->{OptionsImages});
        $labelImages->set_alignment(0,0.5);
        $tablePath->attach($labelImages, 0, 1, 1, 2, 'fill', 'fill', 0, 0);
        $self->{images} = new Gtk2::Entry;
        $self->{images}->set_width_chars(50);
        $tablePath->attach($self->{images}, 1, 2, 1, 2, 'expand', 'fill', 0, 0);
        my $imagesButton = Gtk2::Button->new_from_stock('gtk-open');
        $imagesButton->signal_connect('clicked', \&imagesBrowse, $self);
        $tablePath->attach($imagesButton, 2, 3, 1, 2, 'fill', 'fill', 0, 0);
	

        my $tableMain = new Gtk2::Table(2,2,0);
        $tableMain->set_row_spacings(10);
        $tableMain->set_col_spacings(20);
        $tableMain->set_border_width(0);
        
        my $labelOrder = new Gtk2::Label($parent->{lang}->{OptionsOrder});
        $labelOrder->set_alignment(0,0.5);
		$self->{orderOption} = new Gtk2::OptionMenu();
		$self->{order} = new Gtk2::Menu();
        my @orders = ($parent->{lang}->{OptionsTabs},
                               $parent->{lang}->{OptionsInfo},
                               $parent->{lang}->{OptionsPerso});                           
        foreach (@orders)
		{
		    my $item = Gtk2::MenuItem->new_with_label($_);
		    $self->{order}->append($item);
		}
		$self->{orders} = \@orders;
		$self->{orderOption}->set_menu($self->{order}) ;

        $tableMain->attach($labelOrder, 0, 1, 0, 1, 'fill', 'fill', 0, 0);
        $tableMain->attach($self->{orderOption}, 1, 2, 0, 1, 'fill', 'fill', 0, 0);

        my $labelLang = new Gtk2::Label($parent->{lang}->{OptionsLang});
        $labelLang->set_alignment(0,0.5);
		$self->{langOption} = new Gtk2::OptionMenu();
		$self->{lang} = new Gtk2::Menu();
		my @langs = @GCLang::langsNames;
		foreach (@langs)
		{
		    my $item = Gtk2::MenuItem->new_with_label($_);
		    $self->{lang}->append($item);
		}
		$self->{langs} = \@langs;
		$self->{langOption}->set_menu($self->{lang}) ;
        $tableMain->attach($labelLang, 0, 1, 1, 2, 'fill', 'fill', 0, 0);
        $tableMain->attach($self->{langOption}, 1, 2, 1, 2, 'fill', 'fill', 0, 0);
	
        #$tableMain->attach(Gtk2::HSeparator->new, 0, 2, 2, 3, 'fill', 'fill', 0, 0);

        my $labelWarning = new Gtk2::Label($parent->{lang}->{OptionsWarning});
        $labelWarning->set_use_underline(1);
		$labelWarning->set_line_wrap(1);
		$labelWarning->set_justify('center');
        #$tableMain->attach($labelWarning, 0, 2, 3, 4, 'fill', 'fill', 0, 0);
        
        my $vboxMain = new Gtk2::VBox(0,0);
        $vboxMain->set_border_width(20);
        $vboxMain->pack_start($tableMain,1,1,0);
        $vboxMain->pack_start(Gtk2::HSeparator->new,1,1,10);
        $vboxMain->pack_start($labelWarning,1,1,0);

        my $vboxConvenience = new Gtk2::VBox(0,0);
        $vboxConvenience->set_border_width(20);

        $self->{confirm} = new Gtk2::CheckButton($parent->{lang}->{OptionsRemoveConfirm});
        $self->{confirm}->set_active($options->confirm);
        $vboxConvenience->pack_start($self->{confirm}, 0, 0, 10);
        $self->{autosave} = new Gtk2::CheckButton($parent->{lang}->{OptionsAutoSave});
        $self->{autosave}->set_active($options->autosave);
        $vboxConvenience->pack_start($self->{autosave}, 0, 0, 10);
        $self->{splash} = new Gtk2::CheckButton($parent->{lang}->{OptionsSplash});
        $self->{splash}->set_active($options->splash);
        $self->{splash}->set_active(1) if (! $options->exists('splash'));
        $vboxConvenience->pack_start($self->{splash}, 0, 0, 10);

        ##
        $vboxConvenience->pack_start(Gtk2::HSeparator->new, 1, 1, 0);
        my $labelFormats = new Gtk2::Label($parent->{lang}->{OptionsFormats});
        my $hboxFormats = new Gtk2::HBox(0,0);
		$self->{formats} = new Gtk2::Entry;
        $hboxFormats->pack_start($labelFormats,0,0,0);
        $hboxFormats->pack_start($self->{formats},1,1,5);
        $vboxConvenience->pack_start($hboxFormats, 1,1,5);
        ##
        
        my $tableDisplay1 = new Gtk2::Table(3, 3, 0);
        $tableDisplay1->set_row_spacings(10);
        $tableDisplay1->set_col_spacings(10);
        $tableDisplay1->set_border_width(0);
        $self->{status} = new Gtk2::CheckButton($parent->{lang}->{OptionsStatus});
        $self->{status}->set_active($options->status);
        $tableDisplay1->attach($self->{status}, 0, 2, 0, 1, 'fill', 'fill', 0, 0);

        my $labelToolbar = new Gtk2::Label($parent->{lang}->{OptionsToolbar});
        $labelToolbar->set_alignment(0,0.5);
        $self->{toolbarOption} = new Gtk2::OptionMenu();
		$self->{toolbar} = new Gtk2::Menu();
		my %toolbars = %{$parent->{lang}->{OptionsToolbars}};
		foreach (0..(scalar(keys %toolbars) - 1))
		{
		    my $item = Gtk2::MenuItem->new_with_label($toolbars{$_});
		    $self->{toolbar}->append($item);
		}
        $self->{toolbarOption}->set_menu($self->{toolbar}) ;
        $tableDisplay1->attach($labelToolbar, 0, 1, 1, 2, 'fill', 'fill', 0, 0);
        $tableDisplay1->attach($self->{toolbarOption}, 1, 2, 1, 2, 'fill', 'fill', 0, 0);
        
        my $labelView = new Gtk2::Label($parent->{lang}->{OptionsView});
        $labelView->set_alignment(0,0.5);
        $self->{viewOption} = new Gtk2::OptionMenu();
		$self->{view} = new Gtk2::Menu();
		my %views = %{$parent->{lang}->{OptionsViews}};
		foreach (0..(scalar(keys %views) - 1))
		{
		    my $item = Gtk2::MenuItem->new_with_label($views{$_});
		    $self->{view}->append($item);
		}
        $self->{viewOption}->set_menu($self->{view}) ;
        $tableDisplay1->attach($labelView, 0, 1, 2, 3, 'fill', 'fill', 0, 0);
        $tableDisplay1->attach($self->{viewOption}, 1, 2, 2, 3, 'fill', 'fill', 0, 0);

        $self->{hboxImages} = new Gtk2::HBox(0,0);
        my $labelColumns = new Gtk2::Label($parent->{lang}->{OptionsColumns});
        my  $adj = Gtk2::Adjustment->new(0, 1, 10, 1, 1, 0) ;
        $self->{columns} = Gtk2::SpinButton->new($adj, 0, 0);
        $self->{buttonBg} = new Gtk2::Button($parent->{lang}->{OptionsImagesBg});
        $parent->{tooltips}->set_tip($self->{buttonBg},
                                     $parent->{lang}->{OptionsImagesBgTooltip});
        $self->{buttonBg}->signal_connect('clicked' => sub {
            $self->changeColor('bg');
        });
        $self->{buttonFg} = new Gtk2::Button($parent->{lang}->{OptionsImagesFg});
        $self->{buttonFg}->signal_connect('clicked' => sub {
            $self->changeColor('fg');
        });
        $parent->{tooltips}->set_tip($self->{buttonFg},
                                     $parent->{lang}->{OptionsImagesFgTooltip});
        $self->{hboxImages}->pack_start($labelColumns, 1, 1, 0);
        $self->{hboxImages}->pack_start($self->{columns}, 0, 0, 5);
        $self->{hboxImages}->pack_start($self->{buttonBg}, 0, 0, 5);
        $self->{hboxImages}->pack_start($self->{buttonFg}, 0, 0, 5);
        $self->{viewOption}->signal_connect('changed' => sub {
                my %views = %{$self->{parent}->{lang}->{OptionsViews}};
	            if ($views{1} eq $self->{viewOption}->child->get_label)
                {
                    $self->{hboxImages}->show;
                }
                else
                {
                    $self->{hboxImages}->hide;
                }
	        });
        $tableDisplay1->attach($self->{hboxImages}, 2, 3, 2, 3, 'fill', 'fill', 10, 0);

        my $tableDisplay2 = new Gtk2::Table(2, 2, 0);
        $tableDisplay2->set_row_spacings(10);
        $tableDisplay2->set_col_spacings(10);
        $tableDisplay2->set_border_width(0);
        
        $self->{transform} = new Gtk2::CheckButton($parent->{lang}->{OptionsTransform});
        $tableDisplay2->attach($self->{transform}, 0, 1, 0, 1, 'shrink', 'fill', 0, 0);
        my $labelArticles = new Gtk2::Label($parent->{lang}->{OptionsArticles});
        $labelArticles->set_alignment(1,0.5);
        $tableDisplay2->attach($labelArticles, 0, 1, 1, 2, 'fill', 'fill', 0, 0); 
		$self->{articles} = new Gtk2::Entry;
		#$self->{articles}->set_width_chars(30);
        $tableDisplay2->attach($self->{articles}, 1, 2, 1, 2, 'fill', 'fill', 5, 0);
        $options->articles('le,la,les,l,un,une,des,a,the') if (! $options->exists('articles'));

        my $vboxDisplay = new Gtk2::VBox(0,0);
        $vboxDisplay->set_border_width(20);
        $vboxDisplay->pack_start($tableDisplay1,0,0,0);
        $vboxDisplay->pack_start(Gtk2::HSeparator->new,0,0,10);
        $vboxDisplay->pack_start($tableDisplay2,0,0,0);
        
        my $tableInternet1 = new Gtk2::Table(3,3,0);
        $tableInternet1->set_row_spacings(10);
        $tableInternet1->set_col_spacings(10);
        $tableInternet1->set_border_width(0);
	
		my $pluginLabel = new Gtk2::Label($parent->{lang}->{OptionsPlugins});
        $pluginLabel->set_alignment(0,0.5);
		$self->{pluginOption} = new Gtk2::OptionMenu();
		$self->{plugin} = new Gtk2::Menu();
		my @plugins = ($parent->{lang}->{OptionsAskPlugins},
		  $parent->{lang}->{OptionsPluginsMultiAsk},
		  $parent->{lang}->{OptionsPluginsMulti},
		  @GCPlugins::pluginsNameArray);
		foreach (@plugins)
		{
		    my $item = Gtk2::MenuItem->new_with_label($_);
		    $self->{plugin}->append( $item) ;
		}
		$self->{plugins} = \@plugins;
		$self->{pluginOption}->set_menu($self->{plugin});		
		$self->{pluginList} = new Gtk2::Button($parent->{lang}->{OptionsPluginsList});
		$self->{pluginList}->signal_connect('clicked' => sub {
		  $parent->selectMultiPluginsList;
		});
		$self->{pluginOption}->signal_connect('changed' => sub {
	       if (($self->{pluginOption}->child->get_label eq $parent->{lang}->{OptionsPluginsMulti}) || ($self->{pluginOption}->child->get_label eq $parent->{lang}->{OptionsPluginsMultiAsk}))
           {
               $self->{pluginList}->show;
           }
           else
           {
               $self->{pluginList}->hide;
            }
	    });		
        $self->{askImport} = new Gtk2::CheckButton($parent->{lang}->{OptionsAskImport});
        $tableInternet1->attach($pluginLabel, 0, 1, 0, 1, 'fill', 'fill', 0, 0); 
        $tableInternet1->attach($self->{pluginOption}, 1, 2, 0, 1, 'fill', 'fill', 0, 0); 
        $tableInternet1->attach($self->{pluginList}, 2, 3, 0, 1, 'fill', 'fill', 20, 0);
        $tableInternet1->attach($self->{askImport}, 0, 3, 1, 2, 'fill', 'fill', 0, 0); 

        $self->{searchStop} = new Gtk2::CheckButton($parent->{lang}->{OptionsSearchStop});
        $tableInternet1->attach($self->{searchStop}, 0, 3, 2, 3, 'fill', 'fill', 0, 0) if ($^O !~ /win32/i);
        
        my $tableInternet2 = new Gtk2::Table(3,3,0);
        $tableInternet2->set_row_spacings(10);
        $tableInternet2->set_col_spacings(10);
        $tableInternet2->set_border_width(0);
	
        $self->{proxycb} = new Gtk2::CheckButton($parent->{lang}->{OptionsProxy});
        $self->{proxycb}->set_active($options->proxy);
		$self->{proxyurl} = new Gtk2::Entry;
		$self->{proxyurl}->set_text($options->proxy);
        $self->{proxycb}->signal_connect('clicked' => sub {
	            if ($self->{proxycb}->get_active)
                {
                    $self->{proxyurl}->set_editable(1);
                }
                else
                {
                    $self->{proxyurl}->set_editable(0);
                }
	        });

        $tableInternet2->attach($self->{proxycb}, 0, 1, 0, 1, 'fill', 'fill', 0, 0);
        $tableInternet2->attach($self->{proxyurl}, 1, 2, 0, 1, 'fill', 'shrink', 0, 0);
        
        my $labelFrom = new Gtk2::Label($self->{parent}->{lang}->{OptionsFrom});
        $labelFrom->set_alignment(0,0.5);
        $self->{from} = new Gtk2::Entry;
        $tableInternet2->attach($labelFrom, 0, 1, 1, 2, 'fill', 'fill', 0, 0);
        $tableInternet2->attach($self->{from}, 1, 2, 1, 2, 'fill', 'fill', 0, 0);

        my $mailerLabel = new Gtk2::Label($parent->{lang}->{OptionsMailer});
        $mailerLabel->set_alignment(0,0.5);
		$self->{mailerOption} = new Gtk2::OptionMenu();
		$self->{mailer} = new Gtk2::Menu();
		my @mailers = ('Sendmail', 'SMTP');
		foreach (@mailers)
		{
		    my $item = Gtk2::MenuItem->new_with_label($_);
		    $self->{mailer}->append( $item) ;
		}
		$self->{mailers} = \@mailers;
		$self->{mailerOption}->set_menu($self->{mailer});
        $tableInternet2->attach($mailerLabel, 0, 1, 2, 3, 'fill', 'fill', 0, 0);
        $tableInternet2->attach($self->{mailerOption}, 1, 2, 2, 3, 'fill', 'fill', 0, 0);
        
        $self->{hboxSMTP} = new Gtk2::HBox(0,0);
        my $SMTPLabel = new Gtk2::Label($parent->{lang}->{OptionsSMTP});
        $self->{smtp} = new Gtk2::Entry;
		$self->{smtp}->set_text($options->smtp);
		$self->{smtp}->set_width_chars(20);
        $self->{hboxSMTP}->pack_start($SMTPLabel,0,0,0);
        $self->{hboxSMTP}->pack_start($self->{smtp},0,0,5);
        $tableInternet2->attach($self->{hboxSMTP}, 2, 3, 2, 3, 'fill', 'fill', 0, 0);

        $self->{mailerOption}->signal_connect('changed' => sub {
	            if ('SMTP' eq $self->{mailerOption}->child->get_label)
                {
                    $self->{hboxSMTP}->show;
                }
                else
                {
                    $self->{hboxSMTP}->hide;
                }
	        });
        
        my $vboxInternet = new Gtk2::VBox(0,0);
        $vboxInternet->set_border_width(20);
        $vboxInternet->pack_start($tableInternet1,0,0,0);
        $vboxInternet->pack_start(Gtk2::HSeparator->new,0,0,10);
        $vboxInternet->pack_start($tableInternet2,0,0,0);
        
        
        my $tabs = Gtk2::Notebook->new();
        $tabs->set_tab_pos('left');

        $tabs->append_page($vboxMain, $parent->{lang}->{OptionsMain});  
        $tabs->append_page($vboxDisplay, $parent->{lang}->{OptionsDisplay});  
        $tabs->append_page($tablePath, $parent->{lang}->{OptionsPaths});  
        $tabs->append_page($vboxInternet, $parent->{lang}->{OptionsInternet});  
        $tabs->append_page($vboxConvenience, $parent->{lang}->{OptionsConveniences});  

        $self->vbox->pack_start($tabs, 1, 1, 0);

        $self->{imagesDialog} = new GCFileChooserDialog($parent->{lang}->{OptionsImagesTitle}, $parent, 'select-folder');
        $self->{browserDialog} = new GCFileChooserDialog($parent->{lang}->{OptionsBrowserTitle}, $parent, 'open');

        bless ($self, $class);
        return $self;
    }

}


1;
